@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_templates.py 10213 2017-08-22 09:34:20Z Lavender $
+# $Id: build_templates.py 10330 2017-10-01 01:54:54Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-22 17:34:20 +0800 (週二, 22 八月 2017) $
-# $Revision: 10213 $
+# $Date: 2017-10-01 09:54:54 +0800 (週日, 01 十月 2017) $
+# $Revision: 10330 $
 
 import os
 import sys
@@ -32,16 +32,19 @@ class Command(BaseCommand):
 
     help = 'Start build all template to dst folder.'
     args = '<start folder> <destination folder>'
+    
+    def add_arguments(self, parser):
+        parser.add_argument('start', type=str, help="start folder")
+        parser.add_argument('output', type=str, help="output folder")
+        parser.add_argument(
+            '-o', '--onlyTemplate', 
+            action='store_true',
+            help="Only output template zip. Not have template shop info")
 
     def handle(self, *args, **options):
-        if len(args) < 2:
-            raise CommandError(
-                "You must specify a folder to get template."
-                )
-
-        startPath = args[0]
-        dstPath = args[1]
-
+        startPath = options['start']
+        dstPath = options['output']
+        
         for f in os.listdir(startPath):
             tempPath = os.path.join(startPath, f)
             
@@ -113,8 +116,12 @@ class Command(BaseCommand):
                 continue
 
             # create_zip
-            error = os.system(
-                "%s manage.py create_zip %s" % (sys.executable, dstPath))
+            if not options['onlyTemplate']:
+                error = os.system(
+                    "%s manage.py create_zip %s" % (sys.executable, dstPath))
+            else:
+                error = os.system(
+                    "%s manage.py create_zip %s -o" % (sys.executable, dstPath))
             if not error == 0:
                 logger.error(
                     "create_zip error code: %d, from template: %s" % 
