@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 10213 2017-08-22 09:34:20Z Lavender $
+# $Id: create_zip.py 10330 2017-10-01 01:54:54Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-22 17:34:20 +0800 (週二, 22 八月 2017) $
-# $Revision: 10213 $
+# $Date: 2017-10-01 09:54:54 +0800 (週日, 01 十月 2017) $
+# $Revision: 10330 $
 
 import os
 import shutil
@@ -34,30 +34,29 @@ logger = createLogger(__name__, "CreateZip.log")
 class Command(BaseCommand):
 
     help = 'Create zip file to destination folder.'
-    args = '<destination folder>'
+    
+    def add_arguments(self, parser):
+        parser.add_argument('path', type=str, help="destination folder")
+        parser.add_argument(
+            '-o', '--onlyTemplate', 
+            action='store_true',
+            help="Only output template zip. Not have template shop info")
 
     def handle(self, *args, **options):
-        if len(args) < 1:
-            raise CommandError(
-                "You must specify a folder to get template."
-                )
-
-        
-
         if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
             with open(os.path.join(ROOT_DIR_PATH, 'info.json')) as jsonfile:
                 data = json.load(jsonfile)
 
-        content = ''
-        for root, dirs, files in os.walk(TEMPLATES_DIR_PATH):
-            for temp in files:
-                with open(os.path.join(root, temp)) as f:
-                    content += f.read()
-        data['checksum'] = hashlib.md5(content).hexdigest()
+            content = ''
+            for root, dirs, files in os.walk(TEMPLATES_DIR_PATH):
+                for temp in files:
+                    with open(os.path.join(root, temp)) as f:
+                        content += f.read()
+            data['checksum'] = hashlib.md5(content).hexdigest()
 
-        with open(os.path.join(ROOT_DIR_PATH, 'info.json'), 'w') as f:
-            line = json.dumps(data)
-            f.write(line)
+            with open(os.path.join(ROOT_DIR_PATH, 'info.json'), 'w') as f:
+                line = json.dumps(data)
+                f.write(line)
 
         zip = zipfile.ZipFile(
             os.path.join(ROOT_DIR_PATH, 'template.zip'), mode='w')
@@ -103,20 +102,27 @@ class Command(BaseCommand):
 
         zip.close()
 
-        dst = args[0]
+        dst = options['path']
 
-        zip = zipfile.ZipFile(
-            os.path.join(dst, '%s.zip' % data['upc']), mode='w')
-        zip.write('info.json')
-        
-        for root, dirs, files in os.walk(IMAGES_DIR_PATH):
-            for file in files:
-                path = 'images/%s' % file
-                logger.info("Zip " + path)
-                zip.write(path)
-                
-        zip.write('template.zip')
-        zip.close()
+        if not options['onlyTemplate']:
+            if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
+                zip = zipfile.ZipFile(
+                    os.path.join(dst, '%s.zip' % data['upc']), mode='w')
+                zip.write('info.json')
+            else:
+                zip = zipfile.ZipFile(
+                    os.path.join(dst, '%s.zip' % 'TemplateShop'), mode='w')
+            
+            for root, dirs, files in os.walk(IMAGES_DIR_PATH):
+                for file in files:
+                    path = 'images/%s' % file
+                    logger.info("Zip " + path)
+                    zip.write(path)
+                    
+            zip.write('template.zip')
+            zip.close()
+        else:      
+            shutil.copyfile('./template.zip', os.path.join(dst, 'template.zip'))
         
         if os.path.exists(FIXTURES_DIR_PATH):
             shutil.rmtree(FIXTURES_DIR_PATH)
