@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10318 2017-09-26 06:38:48Z Lavender $
+# $Id: setup.py 10332 2017-10-01 02:54:19Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-09-26 14:38:48 +0800 (週二, 26 九月 2017) $
-# $Revision: 10318 $ 
+# $Date: 2017-10-01 10:54:19 +0800 (週日, 01 十月 2017) $
+# $Revision: 10332 $ 
 
 import os
 import sys
@@ -213,9 +213,15 @@ if __name__ == "__main__":
             import djangocms_installer
         except Exception as e:
             os.system("pip install djangocms-installer")
-        projectName = raw_input(
-            "Django project not found. "
-            "Auto create one by djangocms-installer. Input a project name:")
+        
+        if sys.version_info.major == 3:
+            projectName = input(
+                "Django project not found. "
+                "Auto create one by djangocms-installer. Input a project name:")
+        else:
+            projectName = raw_input(
+                "Django project not found. "
+                "Auto create one by djangocms-installer. Input a project name:")
         path = os.path.join(path, projectName)
         
         if wizard:
@@ -243,6 +249,13 @@ if __name__ == "__main__":
     os.environ['DJANGO_SETTINGS_MODULE'] = settingModule
     
     import django
+    
+    if not (django.VERSION[0] == 1 and django.VERSION[1] <= 10):
+        logger.error(
+            "Your installed Django above 1.10 which is not supported by "
+            "Django CMS 3.4 yet, please reinstall Django or you may encounter "
+            "some issues while using Django CMS.")
+        sys.exit()
     django.setup()
     
     from django.conf import settings
